# bioDP

A package for biological data processing, especially related to metabodirect
## Installation

You can install this package using pip:
```bash
pip install bioDP
```
## Usage

### Command

```bash
bioDP-metabodirect [input_folder] [output_folder and fileName]
```  
 eg.`bioDP-metabodirect C:\data C:\dispose\report.csv`  

`bioDP-metabodirect --help`

### Import Package

```python

```